@@ -208,7 +208,14 @@ class EventRiskForecast(object):
         forecast_length=None,
         prediction_interval=None,
         models_mode="event_risk",
-        model_list=["UnivariateMotif", "MultivariateMotif", "SectionalMotif", "ARCH"],
+        model_list=[
+            "UnivariateMotif",
+            "MultivariateMotif",
+            "SectionalMotif",
+            "ARCH",
+            'MetricMotif',
+            'SeasonalityMotif',
+        ],
         ensemble=None,
         autots_kwargs=None,
         future_regressor_train=None,
@@ -316,6 +323,8 @@ class EventRiskForecast(object):
             "UnivariateMotif",
             "MultivariateMotif",
             "SectionalMotif",
+            'MetricMotif',
+            "SeasonalityMotif",
             "Motif",
             "ARCH",  # simulations not motifs but similar
             "PytorchForecasting",
